@@ -1,6 +1,6 @@
 package Pod::Weaver::PluginBundle::GopherRepellent;
 BEGIN {
-  $Pod::Weaver::PluginBundle::GopherRepellent::VERSION = '0.009007';
+  $Pod::Weaver::PluginBundle::GopherRepellent::VERSION = '1.000007';
 }
 BEGIN {
   $Pod::Weaver::PluginBundle::GopherRepellent::AUTHORITY = 'cpan:RWSTAUNER';
@@ -22,64 +22,81 @@ use Pod::Elemental::Transformer::List ();
 use Pod::Weaver::Config::Assembler;
 sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
 
-our $NAME = join('', '@', (__PACKAGE__ =~ /([^:]+)$/));
+sub _plain {
+	my ($plug) = @_;
+	(my $name = $plug) =~ s/^\W//;
+	return [ $name, _exp($plug), {} ];
+}
+
+sub _bundle_name {
+	my $class = @_ ? ref $_[0] || $_[0] : __PACKAGE__;
+	join('', '@', ($class =~ /([^:]+)$/));
+}
 
 sub mvp_bundle_config {
-  my @plugins;
-  push @plugins, (
-	# plugin
-    [ "$NAME/WikiDoc",     _exp('-WikiDoc'), {} ],
-	# default
-    [ "$NAME/CorePrep",    _exp('@CorePrep'), {} ],
+	my ($self, $bundle) = @_;
+	my @plugins;
 
-	# sections
-	# default
-    [ "$NAME/Name",        _exp('Name'),      {} ],
-    [ "$NAME/Version",     _exp('Version'),   {} ],
+	# NOTE: bundle name gets prepended to each plugin name at the end
 
-    [ "$NAME/Prelude",     _exp('Region'),  { region_name => 'prelude'     } ],
-    [ "$NAME/Synopsis",    _exp('Generic'), { header      => 'SYNOPSIS'    } ],
-    [ "$NAME/Description", _exp('Generic'), { header      => 'DESCRIPTION' } ],
-    [ "$NAME/Overview",    _exp('Generic'), { header      => 'OVERVIEW'    } ],
-	# extra
-    [ "$NAME/Usage",       _exp('Generic'), { header      => 'USAGE'       } ],
+	push @plugins, (
+		# plugin
+		_plain('-WikiDoc'),
+		# default
+		_plain('@CorePrep'),
 
-    #[ "$NAME/Stability",   _exp('Generic'), { header      => 'STABILITY'   } ],
-  );
+		# sections
+		# default
+		_plain('Name'),
+		_plain('Version'),
+
+		[ 'Prelude',     _exp('Region'),  { region_name => 'prelude' } ],
+	);
+
+	for my $plugin (
+		# default
+		[ 'Synopsis',    _exp('Generic'), {} ],
+		[ 'Description', _exp('Generic'), {} ],
+		[ 'Overview',    _exp('Generic'), {} ],
+		# extra
+		[ 'Usage',       _exp('Generic'), {} ],
+
+		# default
+		[ 'Attributes',  _exp('Collect'), { command => 'attr'   } ],
+		[ 'Methods',     _exp('Collect'), { command => 'method' } ],
+		[ 'Functions',   _exp('Collect'), { command => 'func'   } ],
+	) {
+		$plugin->[2]{header} = uc $plugin->[0];
+		push @plugins, $plugin;
+	}
 
 	# default
-  for my $plugin (
-    [ 'Attributes', _exp('Collect'), { command => 'attr'   } ],
-    [ 'Methods',    _exp('Collect'), { command => 'method' } ],
-    [ 'Functions',  _exp('Collect'), { command => 'func'   } ],
-  ) {
-    $plugin->[2]{header} = uc $plugin->[0];
-    push @plugins, $plugin;
-  }
+	push @plugins, (
+		_plain('Leftovers'),
+		[ 'Postlude',    _exp('Region'),    { region_name => 'postlude' } ],
 
-	# default
-  push @plugins, (
-    [ "$NAME/Leftovers", _exp('Leftovers'), {} ],
-    [ "$NAME/postlude",  _exp('Region'),    { region_name => 'postlude' } ],
+		# TODO: consider SeeAlso if it ever allows comments with the links
 
-	# TODO: consider SeeAlso if it ever allows comments with the links
+		# extra
+		# include Support section with various cpan links and github repo
+		[ 'Support',     _exp('Support'),
+			{ repository_content => '', repository_link => 'both' }
+		],
 
-	# extra
-	# include Support section with various cpan links and github repo
-    [ "$NAME/Support",   _exp('Support'),
-		{ repository_content => '', repository_link => 'both' }
-	],
+		# default
+		_plain('Authors'),
+		_plain('Legal'),
 
-	# default
-    [ "$NAME/Authors",   _exp('Authors'),   {} ],
-    [ "$NAME/Legal",     _exp('Legal'),     {} ],
+		# plugins
+		[ 'List',        _exp('-Transformer'), { 'transformer' => 'List' } ],
+		_plain('-StopWords'),
+	);
 
-	# plugins
-	[ "$NAME/List",      _exp('-Transformer'), { 'transformer' => 'List' } ],
-	[ "$NAME/StopWords", _exp('-StopWords'), {} ],
-  );
+	# prepend bundle name to each plugin name
+	my $name = $self->_bundle_name;
+	@plugins = map { $_->[0] = "$name/$_->[0]"; $_ } @plugins;
 
-  return @plugins;
+	return @plugins;
 }
 
 1;
@@ -96,7 +113,7 @@ Pod::Weaver::PluginBundle::GopherRepellent - keep those pesky gophers out of you
 
 =head1 VERSION
 
-version 0.009007
+version 1.000007
 
 =head1 SYNOPSIS
 
